from fastapi import APIRouter, Security
from sqlalchemy import select

from ..core.security import get_current_active_user as get_user
from ..db.session import SessionFuture
from ..models.db_setting import DbSetting
from ..schemas.settings import PrefillCustomerDiscount
from ..schemas.user_token import UserToken


router = APIRouter()


@router.get("/prefill-customer-discount", response_model=PrefillCustomerDiscount)
def get_prefill_customer_discount(
    user: UserToken = Security(get_user),
) -> PrefillCustomerDiscount:
    with SessionFuture() as db:
        value = (
            db.execute(select(DbSetting).where(DbSetting.name == "Prefill Customer Discount"))
            .scalar_one()
            .data["Value"]
        )
        return PrefillCustomerDiscount(value=value)


@router.post("/prefill-customer-discount", response_model=PrefillCustomerDiscount)
def set_prefill_customer_discount(
    data: PrefillCustomerDiscount,
    user: UserToken = Security(get_user, scopes=["settings"]),
) -> PrefillCustomerDiscount:
    with SessionFuture() as db:
        item = db.execute(select(DbSetting).where(DbSetting.name == "Prefill Customer Discount")).scalar_one()
        item.data = {"Value": data.value}
        db.commit()
        return PrefillCustomerDiscount(value=item.data["Value"])
