import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';
import { catchError } from 'rxjs/operators';

import { ErrorLoggerService } from '../core/error-logger.service';
import { Regime } from '../core/regime';

const httpOptions = {
  headers: new HttpHeaders({ 'Content-Type': 'application/json' }),
};
const url = '/api/regimes';
const serviceName = 'RegimeService';

@Injectable({
  providedIn: 'root',
})
export class RegimeService {
  constructor(private http: HttpClient, private log: ErrorLoggerService) {}

  get(id: number | null): Observable<Regime> {
    const getUrl: string = id === null ? url : `${url}/${id}`;
    return this.http
      .get<Regime>(getUrl)
      .pipe(catchError(this.log.handleError(serviceName, `get id=${id}`))) as Observable<Regime>;
  }

  list(): Observable<Regime[]> {
    return this.http
      .get<Regime[]>(`${url}/list`)
      .pipe(catchError(this.log.handleError(serviceName, 'list'))) as Observable<Regime[]>;
  }

  save(regime: Regime): Observable<Regime> {
    return this.http
      .post<Regime>(url, regime, httpOptions)
      .pipe(catchError(this.log.handleError(serviceName, 'save'))) as Observable<Regime>;
  }

  update(regime: Regime): Observable<Regime> {
    return this.http
      .put<Regime>(`${url}/${regime.id}`, regime, httpOptions)
      .pipe(catchError(this.log.handleError(serviceName, 'update'))) as Observable<Regime>;
  }

  saveOrUpdate(regime: Regime): Observable<Regime> {
    if (!regime.id) {
      return this.save(regime);
    }
    return this.update(regime);
  }

  delete(id: number): Observable<Regime> {
    return this.http
      .delete<Regime>(`${url}/${id}`, httpOptions)
      .pipe(catchError(this.log.handleError(serviceName, 'delete'))) as Observable<Regime>;
  }
}
