import { CommonModule } from '@angular/common';
import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';

import { AuthGuard } from '../auth/auth-guard.service';
import { SectionListResolver } from '../sections/section-list-resolver.service';

import { TableDetailComponent } from './table-detail/table-detail.component';
import { TableListComponent } from './table-list/table-list.component';
import { TableListResolver } from './table-list-resolver.service';
import { TableResolver } from './table-resolver.service';

const tablesRoutes: Routes = [
  {
    path: '',
    component: TableListComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Sections',
    },
    resolve: {
      list: TableListResolver,
    },
  },
  {
    path: 'new',
    component: TableDetailComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Sections',
    },
    resolve: {
      item: TableResolver,
      sections: SectionListResolver,
    },
  },
  {
    path: ':id',
    component: TableDetailComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Sections',
    },
    resolve: {
      item: TableResolver,
      sections: SectionListResolver,
    },
  },
];

@NgModule({
  imports: [CommonModule, RouterModule.forChild(tablesRoutes)],
  exports: [RouterModule],
  providers: [TableListResolver, TableResolver],
})
export class TableRoutingModule {}
