import { AfterViewInit, Component, ElementRef, OnInit, ViewChild } from '@angular/core';
import { FormControl, FormGroup } from '@angular/forms';
import { MatDialog } from '@angular/material/dialog';
import { ActivatedRoute, Router } from '@angular/router';
import { round } from 'mathjs';
import { Regime } from 'src/app/core/regime';

import { Tax } from '../../core/tax';
import { ToasterService } from '../../core/toaster.service';
import { ConfirmDialogComponent } from '../../shared/confirm-dialog/confirm-dialog.component';
import { TaxService } from '../tax.service';

@Component({
  selector: 'app-tax-detail',
  templateUrl: './tax-detail.component.html',
  styleUrls: ['./tax-detail.component.css'],
})
export class TaxDetailComponent implements OnInit, AfterViewInit {
  @ViewChild('nameElement', { static: true }) nameElement?: ElementRef;
  form: FormGroup<{
    name: FormControl<string>;
    rate: FormControl<number>;
    regime: FormControl<number>;
  }>;

  item: Tax = new Tax();
  regimes: Regime[] = [];

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private dialog: MatDialog,
    private toaster: ToasterService,
    private ser: TaxService,
  ) {
    // Create form
    this.form = new FormGroup({
      name: new FormControl<string>('', { nonNullable: true }),
      rate: new FormControl<number>(100, { nonNullable: true }),
      regime: new FormControl<number>(0, { nonNullable: true }),
    });
  }

  ngOnInit() {
    this.route.data.subscribe((value) => {
      const data = value as { item: Tax; regimes: Regime[] };
      this.regimes = data.regimes;
      this.showItem(data.item);
    });
  }

  showItem(item: Tax) {
    this.item = item;
    this.form.setValue({
      name: this.item.name ?? '',
      rate: this.item.rate * 100,
      regime: this.item.regime?.id ?? 0,
    });
  }

  ngAfterViewInit() {
    setTimeout(() => {
      if (this.nameElement !== undefined) {
        this.nameElement.nativeElement.focus();
      }
    }, 0);
  }

  save() {
    this.ser.saveOrUpdate(this.getItem()).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/taxes');
      },
      (error) => {
        this.toaster.show('Error', error);
      },
    );
  }

  delete() {
    this.ser.delete(this.item.id as string).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/taxes');
      },
      (error) => {
        this.toaster.show('Error', error);
      },
    );
  }

  confirmDelete(): void {
    const dialogRef = this.dialog.open(ConfirmDialogComponent, {
      width: '250px',
      data: { title: 'Delete Tax?', content: 'Are you sure? This cannot be undone.' },
    });

    dialogRef.afterClosed().subscribe((result: boolean) => {
      if (result) {
        this.delete();
      }
    });
  }

  getItem(): Tax {
    const formModel = this.form.value;
    this.item.name = formModel.name ?? '';
    this.item.rate = round((formModel.rate ?? 0) / 100, 5);
    this.item.regime.id = formModel.regime;
    return this.item;
  }
}
