#!/usr/bin/env bash
set -euo pipefail
parent_path=$( cd "$(dirname "${BASH_SOURCE[0]}")" || exit ; pwd -P )
cd "$parent_path" || exit

./lint.sh

if [ 1 -eq "$#" ]
then
  ./version_bump.sh "$1"
else
  ./version_bump.sh
fi

# Download the package.json for caching
curl --silent 'https://git.tanshu.com/tanshu/barker/raw/tag/latest/bookie/package.json' \
     | sed 's/\"version\": \"[0-9\.]*\"/"version": "0.0.0"/g' \
     > "$parent_path/docker/app/package.json"

# Download the package.json for caching
curl --silent 'https://git.tanshu.com/tanshu/barker/raw/tag/latest/barker/pyproject.toml' \
     | sed 's/version = \"[0-9\.]*\"/version = "0.0.0"/g' \
     > "$parent_path/docker/app/pyproject.toml"

cd "$parent_path/docker/app" || exit
docker build --tag barker:latest .
if [ 1 -eq "$#" ]
then
  docker tag barker:latest "$1"
else
  echo "No version bump"
fi
cd "$parent_path/docker" || exit
docker save barker:latest | bzip2 | pv | ssh tanshu@beacon.tanshu.com 'bunzip2 | sudo docker load'
ansible-playbook --limit=beacon playbook-mhl.yml
ansible-playbook --limit=beacon playbook-chd.yml
ansible-playbook --limit=beacon playbook-pkl.yml
